@@ -185,7 +185,9 @@ class JavaGenerator : public BaseGenerator {
           "import com.google.flatbuffers.DoubleVector;\n"
           "import com.google.flatbuffers.FlatBufferBuilder;\n"
           "import com.google.flatbuffers.FloatVector;\n"
+          "import com.google.flatbuffers.IntVector;\n"
           "import com.google.flatbuffers.LongVector;\n"
+          "import com.google.flatbuffers.ShortVector;\n"
           "import com.google.flatbuffers.StringVector;\n"
           "import com.google.flatbuffers.Struct;\n"
           "import com.google.flatbuffers.Table;\n"
@@ -681,7 +683,7 @@ class JavaGenerator : public BaseGenerator {
       // Force compile time error if not using the same version runtime.
       code += "  public static void ValidateVersion() {";
       code += " Constants.";
-      code += "FLATBUFFERS_22_12_06(); ";
+      code += "FLATBUFFERS_23_1_4(); ";
       code += "}\n";
 
       // Generate a special accessor for the table that when used as the root
